//
// PovRay scene file for a double axe
//
// Author:   Hj. Malthaner
// Email:    hansjoerg.malthaner@gmx.de
// Date:   2016/02/23
//
// Web:      http://opengameart.org/users/varkalandar
//
// This file is available under the GNU general
// public license v2 or newer.
//
// http://www.gnu.org/licenses/gpl-2.0.html
//

global_settings 
{
	max_trace_level 35
}

#declare Cam1 = 
camera 
{
 	orthographic
	location <2.5, 2.5*0.82, 2.5>*1.4
	look_at <0, 0, 0>
}            

camera 
{ 
	Cam1 
}          

light_source 
{ 
	<2.5*20, 100, 2.5*10>
	color rgb <1, 1, 1> 
}

// sky sphere

sphere 
{
	<0,0,0>, 10000

	hollow

	pigment 
  {
    color rgb 1
	}
}	

#declare FM = 3.0;

#declare FLOOR = box 
{
	<-1*FM, -0.0, -1*FM>,
	<1*FM, -0.3, 1*FM>

	texture 
  {
    pigment
    {
      marble
      turbulence 0.7
      scale 0.02
      
      // Earth/Sand
      color_map 
      {
        [0.0 color <35/255, 30/255, 45/255>] 
        [0.2 color <95/255, 80/255, 50/255>] 
        [0.75 color <110/255, 95/255, 60/255>]
        [0.85 color <155/255, 140/255, 80/255>]
        [1.0 color <180/255, 180/255, 180/255>]
      }
      
      quick_color rgb 1
    }

    normal 
    {
      bumps 0.2
      scale 0.02                
    }

    finish 
    {
      ambient 0.2
		}
	}
}


#declare TEX_METAL = 
texture 
{
	pigment 
  { 
		color rgb <0.8, 0.76, 0.72> 
	}

	normal 
  {
		bumps 0.1
		scale 0.2
	}

  finish 
  {
    ambient 0.1
    brilliance 2
    diffuse 0.7
    metallic
    specular 0.3
    roughness 0.1
    reflection 0.1
	}
}
texture 
{
	pigment 
  { 
    bozo
    color_map
    {
      [0.0 color rgb <0.5, 0.4, 0.3>] 
      [0.5 color rgbt <0.5, 0.4, 0.3, 0.9>] 
      [0.6 color rgbt <0, 0, 0, 1>]
    }
    
    turbulence 1
	}

	normal 
  {
		bumps 0.1
		scale 0.2
	}

  finish 
  {
    ambient 0.15
    diffuse 0.7
    specular 0.3
    roughness 0.1
	}
}

#declare TEX_WOOD = 
texture 
{
	pigment 
  {
    wood

    color_map 
    { 
      [0.1 color rgb <0.60, 0.35, 0.20>]
      [0.9 color rgb <0.90, 0.65, 0.30>]
      [1.0 color rgb <0.60, 0.35, 0.20>]
    }
    turbulence <0.06, 0.1, 1000>
    scale <0.03, 0.03, 0.1>
    rotate <1, 1, 0>
	}
	normal 
  {
		bumps 0.4
		scale 0.2
	}
  finish 
  {
    ambient 0.2
    diffuse 0.8
    specular 0.1
    roughness 0.25
	}
}

#declare AXE_DISC = 
intersection 
{
	sphere 
  {
		<-0.9,0,0> 1.1
	}
	sphere 
  {
		<+0.9,0,0> 1.1
	}
  
  scale <0.6, 1, 1>
}

#declare AXE_HEAD = 
union 
{
	difference 
  {
    union
    {
      object 
      {
        AXE_DISC
        scale <1, 1.1, 1>
      }
      object 
      {
        AXE_DISC
        scale <0.8, 1.1, 1.05>
      }
		}

    sphere 
    {
      <0, -1.0, 0>, 0.7
    }

    sphere 
    {
      <0, 1.0, 0>, 0.7
    }
	}

	texture 
  {
		TEX_METAL
	}
}

#declare HANDLE = 
union 
{
  cylinder
  {
    <0, 0, 0>, <0, 2.7, 0>, 0.075
  }
  
  cone
  {
    <0, 0, 0>, 1, <0, 1, 0>, 0.5 
    scale <0.077, 1, 0.12>
  }
  
  scale <0.9, 1, 1.05>
  
  texture
  {
    TEX_WOOD
    
    rotate <90, 0, 0>
  }
}

#declare AXE = 
union 
{
	object 
  {
		AXE_HEAD
    translate <0, 2.3, 0>
  }
  
	object 
  {
		HANDLE
  }
}

union 
{
	object 
  {
		AXE
    rotate <2, 0, 0>
    rotate <0, 0, 1>
    rotate <0, -15, 0>
    translate <-1, 0, 0>
	}

	object 
  {
		AXE
    rotate <0, 0, 90>
    rotate <0, -90, 0>
    rotate <0, 0, -12>
    rotate <2, 0, 0>
    translate <1, 0.075, 1>
	}

	object 
  {
		FLOOR
	}
    
	translate <0, -1, 0>
}
